calview.DailyView (Daily view) — amici1

# `calview.DailyView` (Daily view)

Columns

- `lino.core.actors.Actor.detail_link`

- `lino_xl.lib.calview.ui.DayNavigator.day_number`

- `lino_xl.lib.calview.ui.CalendarView.navigation_panel`

Detail fields

- `<Panel body in lino_xl.lib.calview.ui.DayDetail on lino_xl.lib.calview.ui.DailyView>`

Actions

- HTML (show_as_html) : Show this table in Bootstrap3 interface

- Table (landscape) (as_pdf) : Show this table as a pdf document.

- Table (portrait) (as_pdf_p) : Show this table as a pdf document.

- Export to .xls (export_excel) : Export this table as an .xls document

- Detail (detail) : Open a detail window on this record.

- Create new Event (insert_event) : Custom action for inserting a calendar entry in the DailyView.

- None (open_help) : See `<lino.core.actions.OpenHelpWindow open_help>`.

Filter parameters

- `<django.db.models.fields.related.ForeignKey: user>`

- `<django.db.models.fields.DateField: start_date>`

- `<django.db.models.fields.DateField: end_date>`

- `<lino.core.choicelists.ChoiceListField: observed_event>`

- `<lino.core.choicelists.ChoiceListField: show_appointments>`

- `<django.db.models.fields.related.ForeignKey: presence_guest>`

- `<django.db.models.fields.related.ForeignKey: event_type>`

- `<django.db.models.fields.related.ForeignKey: room>`

- `<lino.core.fields.DummyField object at 0x7fc81cec9518>`

- `<django.db.models.fields.related.ForeignKey: assigned_to>`

- `<lino.core.choicelists.ChoiceListField: state>`

## Filter parameters